@@ -79,9 +79,14 @@ def list_results():
 def fetch_result(dispatch_id):
     with DispatchDB() as db:
         res = db.get([dispatch_id])
-    response = res[0][1]
+    if len(res) > 0:
+        response = res[0][1]
+        status = 200
+    else:
+        response = ""
+        status = 400
 
-    return app.response_class(response, status=200, mimetype="application/json")
+    return app.response_class(response, status=status, mimetype="application/json")
 
 
 @app.route("/api/results", methods=["DELETE"])
